@@ -908,6 +908,7 @@ class Model:
             self.latest_version,
             self.config.mds_host,
             self.config.verify_ssl,
+            self.config.proxies,
         )
 
         self.record_scenario_url(response)
@@ -998,6 +999,7 @@ class Model:
             self.api_headers,
             self.log,
             self.config.verify_ssl,
+            self.config.proxies,
         )
 
         df = pd.json_normalize(drivers)
@@ -1017,7 +1019,12 @@ class Model:
         Get CSIN and latest version for a ticker
         """
         return get_company_info_from_ticker(
-            self.ticker, self.api_headers, self.config.mds_host
+            ticker=self.ticker,
+            auth_headers=self.api_headers,
+            logger=self.log,
+            mds_host=self.config.mds_host,
+            verify_ssl=self.config.verify_ssl,
+            proxies=self.config.proxies,
         )
 
     def get_name_index(self, force=False):
@@ -1179,6 +1186,7 @@ class Model:
             self.log,
             settings.MDS_HOST,
             self.config.verify_ssl,
+            self.config.proxies,
         )
 
         if df_index is not None:
@@ -1332,6 +1340,7 @@ class Model:
             self.log,
             self.config.mds_host,
             self.config.verify_ssl,
+            self.config.proxies,
         )
         if df is not None:
             return df
@@ -1394,6 +1403,7 @@ class Model:
                 self.log,
                 self.config.mds_host,
                 self.config.verify_ssl,
+                self.config.proxies,
             )
             if df is not None:
                 self.default_df = df
@@ -1413,11 +1423,14 @@ class Model:
                 self.log,
                 self.config.mds_host,
                 self.config.verify_ssl,
+                self.config.proxies,
             )
 
         url = get_forecast_url(self.csin, self.latest_version, self.config.mds_host)
 
-        res = get_request(url, self.api_headers, self.log, self.config.verify_ssl)
+        res = get_request(
+            url, self.api_headers, self.log, self.config.verify_ssl, self.config.proxies
+        )
 
         list_out = []
 
@@ -1428,6 +1441,7 @@ class Model:
                 self.api_headers,
                 self.log,
                 self.config.verify_ssl,
+                self.config.proxies,
             )
             list_out.append(df)
 
@@ -1445,6 +1459,7 @@ class Model:
                 logger=self.log,
                 mds_host=self.config.mds_host,
                 verify_ssl=self.config.verify_ssl,
+                proxies=self.config.proxies,
             )
 
         url = get_forecast_url(self.csin, self.latest_version, self.config.mds_host)
@@ -1460,6 +1475,7 @@ class Model:
                 headers=self.api_headers,
                 logger=self.log,
                 verify_ssl=self.config.verify_ssl,
+                proxies=self.config.proxies,
             )
             scenario_json = scenario_response.json()
             scenario_id_url = map_scenario_urls(scenario_json).get(self.uuid)
@@ -1479,15 +1495,27 @@ class Model:
             url = scenario_id_url + "time-series/?name=" + time_series_name
 
             res_loop = get_request(
-                url, self.api_headers, self.log, self.config.verify_ssl
+                url,
+                self.api_headers,
+                self.log,
+                self.config.verify_ssl,
+                self.config.proxies,
             )
             url = res_loop.json()["results"][0]["self"]
             res_loop = get_request(
-                url, self.api_headers, self.log, self.config.verify_ssl
+                url,
+                self.api_headers,
+                self.log,
+                self.config.verify_ssl,
+                self.config.proxies,
             )
             url = res_loop.json()["forecast_data_points"]
             res_loop = get_request(
-                url, self.api_headers, self.log, self.config.verify_ssl
+                url,
+                self.api_headers,
+                self.log,
+                self.config.verify_ssl,
+                self.config.proxies,
             )
             res_data = res_loop.json()["results"]
             dict_out = {}
@@ -1531,6 +1559,7 @@ class Model:
             headers=self.api_headers,
             logger=self.log,
             verify_ssl=self.config.verify_ssl,
+            proxies=self.config.proxies,
         )
         all_df = []
 
@@ -1540,6 +1569,7 @@ class Model:
                 self.ticker,
                 self.api_headers,
                 verify_ssl=self.config.verify_ssl,
+                proxies=self.config.proxies,
             )
             for res_dict in scenario_response.json()["results"]
         )
