@@ -6,8 +6,7 @@ import numpy as np
 import pandas as pd
 from pandas.core.frame import DataFrame
 
-from canalyst_candas.settings import CONFIG
-from canalyst_candas.configuration.config import Config
+from canalyst_candas.configuration.config import Config, create_config
 from canalyst_candas.utils.requests import Getter
 
 
@@ -31,7 +30,7 @@ class Search:
     """
 
     def __init__(self, config: Config = None) -> None:
-        self.config: Config = config or CONFIG
+        self.config: Config = config or create_config()
         self.df_search: Optional[DataFrame] = None
         self.df_guidance: Optional[DataFrame] = None
         self.ticker_list: Optional[List[str]] = None
