@@ -1,7 +1,7 @@
 import unittest
 from canalyst_candas import settings
 
-from canalyst_candas.utils import get_forecast_url
+from canalyst_candas.utils.transformations import get_forecast_url
 
 
 class BaseUtilsTests(unittest.TestCase):
