@@ -10,14 +10,10 @@ from unittest.mock import Mock, patch
 import pandas
 from requests.models import Response
 
-from canalyst_candas import settings
-
-from canalyst_candas.utils import (
-    LogFile,
-    BulkDataKeys,
-    _get_mds_bulk_data_url,
-    get_data_set_from_mds,
-)
+from canalyst_candas.settings import BulkDataKeys
+from canalyst_candas.utils.logger import LogFile
+from canalyst_candas.utils.transformations import _get_mds_bulk_data_url
+from canalyst_candas.utils.requests import get_data_set_from_mds
 
 
 class MdsBulkDataUtilsTests(unittest.TestCase):
@@ -28,7 +24,9 @@ class MdsBulkDataUtilsTests(unittest.TestCase):
     def setUp(self) -> None:
         self.mock_log = Mock(spec=LogFile)
 
-        self.mock_get_request = patch("canalyst_candas.utils.get_request").start()
+        self.mock_get_request = patch(
+            "canalyst_candas.utils.requests.get_request"
+        ).start()
 
     def tearDown(self):
         sys.stdout = sys.__stdout__
