@@ -2,8 +2,8 @@ import unittest
 import json
 from unittest.mock import Mock, patch
 
-from canalyst_candas.utils import (
-    LogFile,
+from canalyst_candas.utils.logger import LogFile
+from canalyst_candas.utils.requests import (
     get_company_info_from_ticker,
     get_csin_from_ticker,
     get_historical_periods,
@@ -13,7 +13,7 @@ from canalyst_candas.utils import (
 
 class MdsGetHistoricalPeriodsTests(unittest.TestCase):
     """
-    Tests for util methods that hit the {canalyst_candas.utils.PERIODS_URL} url using a ticker.
+    Tests for util methods that hit the {canalyst_candas.settings.PERIODS_URL} url using a ticker.
     """
 
     def setUp(self) -> None:
@@ -373,7 +373,7 @@ class MdsGetHistoricalPeriodsTests(unittest.TestCase):
         self.json_response = json.loads(self.ex_json_str)
         self.mock_log = Mock(spec=LogFile)
         self.mock_get_request_json_content = patch(
-            "canalyst_candas.utils.get_request_json_content"
+            "canalyst_candas.utils.requests.get_request_json_content"
         ).start()
 
     def tearDown(self):
