@@ -2,8 +2,8 @@ import unittest
 import json
 from unittest.mock import Mock, patch
 
-from canalyst_candas.utils import (
-    LogFile,
+from canalyst_candas.utils.logger import LogFile
+from canalyst_candas.utils.requests import (
     get_company_info_from_ticker,
     get_csin_from_ticker,
     get_model_info,
@@ -12,7 +12,7 @@ from canalyst_candas.utils import (
 
 class MdsGetInfoFromTickerTests(unittest.TestCase):
     """
-    Tests for util methods that hit the {canalyst_candas.utils.CSIN_URL} url using a ticker.
+    Tests for util methods that hit the {canalyst_candas.settings.CSIN_URL} url using a ticker.
 
     - get_company_info_from_ticker()
     - get_csin_from_ticker()
@@ -60,10 +60,10 @@ class MdsGetInfoFromTickerTests(unittest.TestCase):
         ]["name"]
         self.mock_log = Mock(spec=LogFile)
         self.mock_get_request_json_content = patch(
-            "canalyst_candas.utils.get_request_json_content"
+            "canalyst_candas.utils.requests.get_request_json_content"
         ).start()
         self.mock_get_historical_periods = patch(
-            "canalyst_candas.utils.get_historical_periods"
+            "canalyst_candas.utils.requests.get_historical_periods"
         ).start()
 
     def tearDown(self):
