@@ -2,7 +2,7 @@
 GetSampleDrivers tests module
 """
 import unittest
-from canalyst_candas.utils import get_sample_drivers
+from canalyst_candas.utils.requests import get_sample_drivers
 
 
 class GetSampleDrivers(unittest.TestCase):
