@@ -5,8 +5,8 @@ Test module for GetTestData set
 import unittest
 
 from canalyst_candas.exceptions import BaseCandasException
-from canalyst_candas.utils import get_test_data_set
-from canalyst_candas.utils import BulkDataKeys
+from canalyst_candas.utils.requests import get_test_data_set
+from canalyst_candas.settings import BulkDataKeys
 
 
 class TestGetTestDataSet(unittest.TestCase):
