@@ -1,6 +1,7 @@
 """
 Utilities for making resource requests 
 """
+import botocore
 import json
 import pickle
 import os
@@ -50,6 +51,7 @@ class Getter:
             aws_access_key_id=self.config.s3_access_key_id,
             aws_secret_access_key=self.config.s3_secret_key,
             verify=config.verify_ssl,
+            config=botocore.config.Config(proxies=self.config.proxies),
         )
 
     def get_s3_file(self, to_filename, from_filename):
@@ -185,15 +187,19 @@ def check_throttle_limit(response, logger):
     return False
 
 
-def get_request(url, headers, logger, verify_ssl=settings.VERIFY_SSL):
+def get_request(
+    url, headers, logger, verify_ssl=settings.VERIFY_SSL, proxies=settings.PROXIES
+):
     """
     Wrapper for a GET request
 
     Handles throttle limits by using a timer
     """
-    response = requests.get(url=url, headers=headers, verify=verify_ssl)
+    response = requests.get(
+        url=url, headers=headers, verify=verify_ssl, proxies=proxies
+    )
     if check_throttle_limit(response, logger):
-        response = requests.get(url=url, headers=headers, verify=False)
+        response = requests.get(url=url, headers=headers, verify=False, proxies=proxies)
     if response.status_code == 401:
         raise HTTPClientException(
             f"HTTP Error code : {response.status_code}. Check Canalyst API key"
@@ -209,26 +215,32 @@ def get_request(url, headers, logger, verify_ssl=settings.VERIFY_SSL):
     return response
 
 
-def post_request(url, headers, json, verify_ssl):
+def post_request(url, headers, json, verify_ssl, proxies):
     """
     POST request helper function
 
     Uses timer to account for throttle limits.
     """
-    response = requests.post(url=url, headers=headers, json=json, verify=verify_ssl)
+    response = requests.post(
+        url=url, headers=headers, json=json, verify=verify_ssl, proxies=proxies
+    )
     if check_throttle_limit(response):
-        response = requests.post(url=url, headers=headers, json=json, verify=verify_ssl)
+        response = requests.post(
+            url=url, headers=headers, json=json, verify=verify_ssl, proxies=proxies
+        )
 
     return response
 
 
-def get_request_json_content(url, headers, logger, verify_ssl=settings.VERIFY_SSL):
+def get_request_json_content(
+    url, headers, logger, verify_ssl=settings.VERIFY_SSL, proxies=settings.PROXIES
+):
     """
     Make a GET request to a URL that responds with JSON content
 
     Returns the deserialized response content
     """
-    return get_request(url, headers, logger, verify_ssl).json()
+    return get_request(url, headers, logger, verify_ssl, proxies).json()
 
 
 def set_api_key(key, key_file_path):
@@ -269,6 +281,7 @@ def get_data_set_from_mds(
     log: LogFile,
     mds_host: str = settings.MDS_HOST,
     verify_ssl=settings.VERIFY_SSL,
+    proxies=settings.PROXIES,
 ):
     """
     Pulls a bulk data file from the MDS at the equity-model endpoint and returns it in a dataframe.
@@ -292,7 +305,7 @@ def get_data_set_from_mds(
         model_version,
         mds_host,
     )
-    response = get_request(url, auth_headers, log, verify_ssl)
+    response = get_request(url, auth_headers, log, verify_ssl, proxies)
     # parquet not available: fallback to csv
     if response is None:
         url = _get_mds_bulk_data_url(
@@ -302,7 +315,7 @@ def get_data_set_from_mds(
             model_version,
             mds_host,
         )
-        response = get_request(url, auth_headers, log, verify_ssl)
+        response = get_request(url, auth_headers, log, verify_ssl, proxies)
         file_type = "csv"
 
     if file_type == settings.BulkDataFileType.CSV.value:
@@ -368,13 +381,18 @@ def get_company_info_from_ticker(
     logger: LogFile,
     mds_host=settings.MDS_HOST,
     verify_ssl=settings.VERIFY_SSL,
+    proxies=settings.PROXIES,
 ):
     """
     Get CSIN and latest version for a ticker
     """
     company_url = f"{mds_host}/{settings.CSIN_URL.format(ticker=quote_plus(ticker))}"
     response_content = get_request_json_content(
-        company_url, auth_headers, logger, verify_ssl
+        url=company_url,
+        headers=auth_headers,
+        logger=logger,
+        verify_ssl=verify_ssl,
+        proxies=proxies,
     )
 
     try:
@@ -398,13 +416,14 @@ def send_scenario(
     latest_version="",
     mds_host=settings.MDS_HOST,
     verify_ssl=settings.VERIFY_SSL,
+    proxies=settings.PROXIES,
 ):
     """
     Makes a POST request for scenario to the MDS
     """
     if csin == "" or latest_version == "":
         csin, latest_version = get_company_info_from_ticker(
-            ticker, auth_headers, logger, mds_host, verify_ssl
+            ticker, auth_headers, logger, mds_host, verify_ssl, proxies
         )
     scenario_url = (
         f"{mds_host}/{settings.SCENARIO_URL.format(csin=csin, version=latest_version)}"
@@ -412,7 +431,11 @@ def send_scenario(
     # print("scenario_url: " + scenario_url)
     try:
         scenario_response = post_request(
-            url=scenario_url, headers=auth_headers, json=data, verify_ssl=verify_ssl
+            url=scenario_url,
+            headers=auth_headers,
+            json=data,
+            verify_ssl=verify_ssl,
+            proxies=proxies,
         )
     except:
         return None
@@ -427,15 +450,23 @@ def get_scenarios(
     logger: LogFile,
     mds_host=settings.MDS_HOST,
     verify_ssl=settings.VERIFY_SSL,
+    proxies=settings.PROXIES,
 ):
     # TODO: possible unused function: delete if necessary
     if ticker == "":
         ticker = ticker
     url = f"{mds_host}/api/scenarios/"
     csin, latest_version = get_company_info_from_ticker(
-        ticker, auth_headers, logger, mds_host, verify_ssl
+        ticker,
+        auth_headers,
+        logger,
+        mds_host,
+        verify_ssl,
+        proxies,
+    )
+    response_content = get_request_json_content(
+        url, auth_headers, logger, verify_ssl, proxies
     )
-    response_content = get_request_json_content(url, auth_headers, logger, verify_ssl)
     res = response_content.get("results")
     list_out = []
     for i in res:
@@ -455,13 +486,18 @@ def get_csin_from_ticker(
     logger: LogFile,
     mds_host=settings.MDS_HOST,
     verify_ssl=settings.VERIFY_SSL,
+    proxies=settings.PROXIES,
 ):
     """
     Get CSIN for ticker
     """
     company_url = f"{mds_host}/{settings.CSIN_URL.format(ticker=quote_plus(ticker))}"
     response_content = get_request_json_content(
-        company_url, auth_headers, logger, verify_ssl
+        company_url,
+        auth_headers,
+        logger,
+        verify_ssl,
+        proxies,
     )
     json = response_content.get("results")[0]
     csin = json.get("csin")
@@ -481,7 +517,12 @@ def get_excel_model(config, ticker="", download_dir="", logger=None):
         default_dir = download_dir
 
     csin = get_csin_from_ticker(
-        ticker, auth_headers, logger, mds_host, config.verify_ssl
+        ticker,
+        auth_headers,
+        logger,
+        mds_host,
+        config.verify_ssl,
+        config.proxies,
     )
 
     client = GraphqlClient(endpoint=f"{wp_host}/model-workbooks")
@@ -537,7 +578,9 @@ def get_excel_model(config, ticker="", download_dir="", logger=None):
         os.rename(file_name, backup_name)
         print("Backup to: " + backup_name)
 
-    r = requests.get(url, headers=auth_headers, verify=config.verify_ssl)
+    r = requests.get(
+        url, headers=auth_headers, verify=config.verify_ssl, proxies=config.proxies
+    )
 
     with open(file_name, "wb") as f:
         f.write(r.content)
@@ -547,15 +590,20 @@ def get_excel_model(config, ticker="", download_dir="", logger=None):
 
 
 def get_forecast_url_data(
-    res_dict, ticker, auth_headers, log, verify_ssl=settings.VERIFY_SSL
+    res_dict,
+    ticker,
+    auth_headers,
+    log,
+    verify_ssl=settings.VERIFY_SSL,
+    proxies=settings.PROXIES,
 ):
     list_out = []
     url = res_dict["self"]
 
-    res_loop = get_request(url, auth_headers, log, verify_ssl)
+    res_loop = get_request(url, auth_headers, log, verify_ssl, proxies)
     url = res_loop.json()["data_points"]
 
-    res_loop = get_request(url, auth_headers, log, verify_ssl)
+    res_loop = get_request(url, auth_headers, log, verify_ssl, proxies)
     # try:
     next_url = res_loop.json()["next"]
     # except:
@@ -601,7 +649,7 @@ def get_forecast_url_data(
             list_out.append(df)
         url = next_url
         try:
-            res_loop = get_request(url, auth_headers, log, verify_ssl)
+            res_loop = get_request(url, auth_headers, log, verify_ssl, proxies)
             next_url = res_loop.json()["next"]
         except:
             url = None
@@ -614,14 +662,15 @@ def get_scenario_url_data(
     auth_headers,
     default_dir=settings.DEFAULT_DIR,
     verify_ssl=settings.VERIFY_SSL,
+    proxies=settings.PROXIES,
 ):
     log = LogFile(default_dir=default_dir)
     url = res_dict["self"]
 
-    res_loop = get_request(url, auth_headers, log, verify_ssl)
+    res_loop = get_request(url, auth_headers, log, verify_ssl, proxies)
     url = res_loop.json()["data_points"]
 
-    res_loop = get_request(url, auth_headers, log, verify_ssl)
+    res_loop = get_request(url, auth_headers, log, verify_ssl, proxies)
 
     try:
         res_data = res_loop.json()["results"]
@@ -661,7 +710,7 @@ def get_scenario_url_data(
             df = pd.DataFrame.from_dict(dict_out, orient="index").T
             list_out.append(df)
         try:
-            res_loop = get_request(url, auth_headers, log, verify_ssl)
+            res_loop = get_request(url, auth_headers, log, verify_ssl, proxies)
             res_data = res_loop.json()["results"]
             url = res_loop.json()["next"]
         except:
@@ -704,14 +753,21 @@ def create_drivers_dot(
         return path_name
     else:
         csin, version = get_company_info_from_ticker(
-            ticker, auth_headers, logger, config.mds_host, config.verify_ssl
+            ticker,
+            auth_headers,
+            logger,
+            config.mds_host,
+            config.verify_ssl,
+            config.proxies,
         )
         url = (
             f"{config.mds_host}/api/equity-model-series/{csin}/equity-models/"
             f"{version}/time-series/{time_series}/forecast-data-points/"
         )
 
-        r = requests.get(url, headers=auth_headers, verify=config.verify_ssl)
+        r = requests.get(
+            url, headers=auth_headers, verify=config.verify_ssl, proxies=config.proxies
+        )
         json = r.json().get("results")[0]
         name = json["period"]["name"]
         url = (
@@ -721,7 +777,9 @@ def create_drivers_dot(
         )
 
         print(url)
-        r = requests.get(url, headers=auth_headers, verify=config.verify_ssl)
+        r = requests.get(
+            url, headers=auth_headers, verify=config.verify_ssl, proxies=config.proxies
+        )
         with open(path_name, "wb") as f:
             f.write(r.content)
         return path_name
@@ -735,12 +793,17 @@ def get_historical_periods(
     log,
     num_of_periods_to_fetch=settings.HISTORICAL_PERIODS_TO_FETCH,
     verify_ssl=settings.VERIFY_SSL,
+    proxies=settings.PROXIES,
 ):
     periods_url = (
         f"{mds_host}/{settings.PERIODS_URL.format(csin=csin, version=version)}"
     )
     periods_response = get_request_json_content(
-        periods_url, auth_headers, log, verify_ssl
+        periods_url,
+        auth_headers,
+        log,
+        verify_ssl,
+        proxies,
     )
     periods_json = periods_response.get("results")
     periods = [period.get("name") for period in periods_json[:num_of_periods_to_fetch]]
@@ -754,6 +817,7 @@ def get_model_info(
     log: LogFile,
     mds_host=settings.MDS_HOST,
     verify_ssl=settings.VERIFY_SSL,
+    proxies=settings.PROXIES,
 ):
     """
     Retrieve latest equity model information and historical datapoints endpoint url
@@ -763,7 +827,11 @@ def get_model_info(
     company_url = f"{mds_host}/{settings.CSIN_URL.format(ticker=quote_plus(ticker))}"
 
     company_response = get_request_json_content(
-        company_url, auth_headers, log, verify_ssl
+        company_url,
+        auth_headers,
+        log,
+        verify_ssl,
+        proxies,
     )
     json = company_response.get("results")[0]
     csin = json.get("csin")
@@ -784,6 +852,7 @@ def get_model_info(
         log,
         settings.HISTORICAL_PERIODS_TO_FETCH,
         verify_ssl,
+        proxies,
     )
 
     model_info[ticker] = (
@@ -812,6 +881,7 @@ def crawl_company_pages(
     logger: LogFile,
     default_dir=settings.DEFAULT_DIR,
     verify_ssl=settings.VERIFY_SSL,
+    proxies=settings.PROXIES,
 ):
     """
     Retreive data from url and subsequent pages.
@@ -823,7 +893,11 @@ def crawl_company_pages(
     page_number = 1
     while next_url is not None:
         response_content = get_request_json_content(
-            next_url, auth_headers, logger, verify_ssl
+            next_url,
+            auth_headers,
+            logger,
+            verify_ssl,
+            proxies,
         )
         response = response_content.get(key_name)
         next_url = response_content.get(next_name)
@@ -898,6 +972,7 @@ def get_forecast_period_name(
     api_headers,
     logger,
     verify_ssl=settings.VERIFY_SSL,
+    proxies=settings.PROXIES,
 ):
     """
     Retrieve the first forecast period name
@@ -907,13 +982,15 @@ def get_forecast_period_name(
     )
     forecast_endpoint = f"{mds_host}/{forecast_url.format(csin=quote_plus(csin), model_version=quote_plus(model_version))}"
     try:
-        response = requests.get(forecast_endpoint, headers=api_headers)
+        response = requests.get(
+            forecast_endpoint, headers=api_headers, verify=verify_ssl, proxies=proxies
+        )
     except:
         print(f"Candas: Error with getting forecast period.")
         return
 
     response_content = get_request_json_content(
-        forecast_endpoint, api_headers, logger, verify_ssl
+        forecast_endpoint, api_headers, logger, verify_ssl, proxies
     )
 
     forecast_period_name = response_content["results"][0]["name"]
@@ -933,7 +1010,13 @@ def get_sample_drivers(ticker: str):
 
 
 def get_drivers_from_api(
-    mds_host, csin, model_version, api_headers, logger, verify_ssl
+    mds_host,
+    csin,
+    model_version,
+    api_headers,
+    logger,
+    verify_ssl,
+    proxies,
 ):
     """
     Returns a list of drivers for the model with the specified CSIN and model version
@@ -941,7 +1024,7 @@ def get_drivers_from_api(
     driver_list = []
 
     forecast_period_name = get_forecast_period_name(
-        mds_host, csin, model_version, api_headers, logger, verify_ssl
+        mds_host, csin, model_version, api_headers, logger, verify_ssl, proxies
     )
 
     driver_url = "api/equity-model-series/{csin}/equity-models/{model_version}/forecast-periods/{period}/data-points/?is_driver=true&page_size=200"
@@ -950,7 +1033,11 @@ def get_drivers_from_api(
 
     while next_url is not None:
         json = get_request_json_content(
-            next_url, headers=api_headers, logger=logger, verify_ssl=verify_ssl
+            next_url,
+            headers=api_headers,
+            logger=logger,
+            verify_ssl=verify_ssl,
+            proxies=proxies,
         )
         drivers = json.get("results")
         next_url = json.get("next")
