@@ -37,6 +37,12 @@ def _get_mds_bulk_data_url(
     )
 
 
+def _get_mds_time_series_url(
+    csin: str, time_series_name: str, mds_host: str = settings.MDS_HOST
+):
+    return f"{mds_host}/{settings.TIME_SERIES_URL.format(csin=csin, time_series_name=time_series_name)}"
+
+
 def save_guidance_csv(df, ticker, filename):
     """
     Save guidance CSV
